kedro.framework.hooks — Kedro 0.17.6 documentation

# kedro.framework.hooks

Description

`kedro.framework.hooks` provides primitives to use hooks to extend KedroContext’s behaviour

Modules

`kedro.framework.hooks.manager` | This module provides an utility function to retrieve the global hook_manager singleton in a Kedro’s execution process.
`kedro.framework.hooks.markers` | This module provides markers to declare Kedro’s hook specs and implementations.
`kedro.framework.hooks.specs` | A module containing specifications for all callable hooks in the Kedro’s execution timeline.